Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Kendra.

Actions, resources, and condition keys for Amazon Kendra - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Kendra

Amazon Kendra (service prefix: `kendra` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Kendra
- Resource types defined by Amazon Kendra
- Condition keys for Amazon Kendra

## Actions defined by Amazon Kendra

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchDeleteDocument | Grant permission to batch delete document | Write | index* |  |
BatchPutDocument | Grant permission to batch put document | Write | index* |  |
CreateDataSource | Grant permission to create a data source | Write | index* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateFaq | Grant permission to create an Faq | Write | index* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateIndex | Grant permission to create an Index | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateThesaurus | Grant permission to create a Thesaurus | Write | index* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteDataSource | Grant permission to delete a data source | Write | data-source* |  |
index* |  |
DeleteFaq | Grant permission to delete an Faq | Write | faq* |  |
index* |  |
DeleteIndex | Grant permission to delete an Index | Write | index* |  |
DeleteThesaurus | Grant permission to delete a Thesaurus | Write | index* |  |
thesaurus* |  |
DescribeDataSource | Grant permission to describe a data source | Read | data-source* |  |
index* |  |
DescribeFaq | Grant permission to describe an Faq | Read | faq* |  |
index* |  |
DescribeIndex | Grant permission to describe an Index | Read | index* |  |
DescribeThesaurus | Grant permission to describe a Thesaurus | Read | index* |  |
thesaurus* |  |
ListDataSourceSyncJobs | Grant permission to get Data Source sync job history | List | data-source* |  |
index* |  |
ListDataSources | Grant permission to list the data sources | List | index* |  |
ListFaqs | Grant permission to list the Faqs | List | index* |  |
ListIndices | Grant permission to list the indexes | List |  |  |
ListTagsForResource | Grant permission to list tags for a resource | List | data-source |  |
faq |  |
index |  |
thesaurus |  |
ListThesauri | Grant permission to list the Thesauri | List | index* |  |
Query | Grant permission to query documents and faqs | Read | index* |  |
StartDataSourceSyncJob | Grant permission to start Data Source sync job | Write | data-source* |  |
index* |  |
StopDataSourceSyncJob | Grant permission to stop Data Source sync job | Write | data-source* |  |
index* |  |
SubmitFeedback | Grant permission to send feedback about a query results | Write | index* |  |
TagResource | Grant permission to tag a resource with given key value pairs | Tagging | data-source |  |
faq |  |
index |  |
thesaurus |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grant permission to remove the tag with the given key from a resource | Tagging | data-source |  |
faq |  |
index |  |
thesaurus |  |
| aws:TagKeys |
UpdateDataSource | Grant permission to update a data source | Write | data-source* |  |
index* |  |
UpdateIndex | Grant permission to update an Index | Write | index* |  |
UpdateThesaurus | Grant permission to update a thesaurus | Write | index* |  |
thesaurus* |  |

## Resource types defined by Amazon Kendra

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
index | `arn:$ { Partition}:kendra:$ { Region}:$ { Account}:index/$ { IndexId}` | aws:ResourceTag/${TagKey}
data-source | `arn:$ { Partition}:kendra:$ { Region}:$ { Account}:index/$ { IndexId}/data-source/$ { DataSourceId}` | aws:ResourceTag/${TagKey}
faq | `arn:$ { Partition}:kendra:$ { Region}:$ { Account}:index/$ { IndexId}/faq/$ { FaqId}` | aws:ResourceTag/${TagKey}
thesaurus | `arn:$ { Partition}:kendra:$ { Region}:$ { Account}:index/$ { IndexId}/thesaurus/$ { ThesaurusId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Kendra

Amazon Kendra defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters create requests based on the allowed set of values for each of the mandatory tags | String
aws:ResourceTag/${TagKey} | Filters actions based on the tag value associated with the resource | String
aws:TagKeys | Filters create requests based on the presence of mandatory tags in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.